@@ -190,15 +190,16 @@ Filter::Filter() :
 
 Filter::~Filter()
 {
-    QListIterator<HotSpot *> iter(_hotspotList);
-    while (iter.hasNext()) {
-        delete iter.next();
-    }
+    reset();
 }
 
 void Filter::reset()
 {
     _hotspots.clear();
+    QListIterator<HotSpot *> iter(_hotspotList);
+    while (iter.hasNext()) {
+        delete iter.next();
+    }
     _hotspotList.clear();
 }
 
@@ -567,7 +568,7 @@ void FileFilter::HotSpot::activate(QObject *)
     new KRun(QUrl::fromLocalFile(_filePath), QApplication::activeWindow());
 }
 
-static QString createFileRegex(const QStringList &patterns, const QString &filePattern, const QString pathPattern)
+static QString createFileRegex(const QStringList &patterns, const QString &filePattern, const QString &pathPattern)
 {
     QStringList suffixes = patterns.filter(QRegularExpression(QStringLiteral("^\\*") + filePattern + QStringLiteral("$")));
     QStringList prefixes = patterns.filter(QRegularExpression(QStringLiteral("^") + filePattern + QStringLiteral("+\\*$")));
